@@ -6,7 +6,7 @@
 use v5.8;
 
 package Term::Tmux::Layout;
-$Term::Tmux::Layout::VERSION = '1.002';
+$Term::Tmux::Layout::VERSION = '1.003';
 # ABSTRACT: Create tmux layout strings programmatically
 
 use strict;
@@ -20,7 +20,7 @@ use namespace::autoclean;
 
 
 sub set_layout {
-    if ($#_ >= 1) { confess 'invalid call' }
+    if ($#_ < 1) { confess 'invalid call' }
     my ($self, @def) = @_;
 
     my ($x, $y) = $self->get_window_size();
@@ -395,7 +395,7 @@ Term::Tmux::Layout - Create tmux layout strings programmatically
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 SYNOPSIS
 
